# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/data/point_cloud.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..data import frame_pb2 as blickfeld_dot_data_dot_frame__pb2
from ..data import scanline_pb2 as blickfeld_dot_data_dot_scanline__pb2
from .. import options_pb2 as blickfeld_dot_options__pb2
from ..update import hardware_pb2 as blickfeld_dot_update_dot_hardware__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/data/point_cloud.proto',
  package='blickfeld.protocol.data',
  syntax='proto2',
  serialized_options=_b('\370\001\001'),
  serialized_pb=_b('\n blickfeld/data/point_cloud.proto\x12\x17\x62lickfeld.protocol.data\x1a\x1a\x62lickfeld/data/frame.proto\x1a\x1d\x62lickfeld/data/scanline.proto\x1a\x17\x62lickfeld/options.proto\x1a\x1f\x62lickfeld/update/hardware.proto\"\xb3\x03\n\nPointCloud\x12<\n\x06header\x18\x03 \x01(\x0b\x32*.blickfeld.protocol.data.PointCloud.HeaderH\x00\x12/\n\x05\x66rame\x18\x01 \x01(\x0b\x32\x1e.blickfeld.protocol.data.FrameH\x00\x12\x35\n\x08scanline\x18\x02 \x01(\x0b\x32!.blickfeld.protocol.data.ScanlineH\x00\x1a\xf6\x01\n\x06Header\x12\'\n\x19legacy_cube_serial_number\x18\x01 \x01(\tB\x04\xb0\xb5\x18\x01\x12/\n\x12\x63ube_serial_number\x18\x02 \x01(\tB\x13\xd0\xb5\x18\x01\xaa\xb5\x18\x0b[A-Z2-7]{9}\x12\x15\n\rstart_time_ns\x18\x03 \x01(\x04\x12\x35\n\x10\x66irmware_version\x18\x04 \x01(\tB\x1b\xaa\xb5\x18\x17v[0-9]+\\.[0-9]+\\.[0-9]+\x12\x44\n\x10hardware_variant\x18\x05 \x01(\x0e\x32*.blickfeld.protocol.update.HardwareVariantB\x06\n\x04\x64\x61taB\x03\xf8\x01\x01')
  ,
  dependencies=[blickfeld_dot_data_dot_frame__pb2.DESCRIPTOR,blickfeld_dot_data_dot_scanline__pb2.DESCRIPTOR,blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_update_dot_hardware__pb2.DESCRIPTOR,])




_POINTCLOUD_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='blickfeld.protocol.data.PointCloud.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='legacy_cube_serial_number', full_name='blickfeld.protocol.data.PointCloud.Header.legacy_cube_serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cube_serial_number', full_name='blickfeld.protocol.data.PointCloud.Header.cube_serial_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\320\265\030\001\252\265\030\013[A-Z2-7]{9}'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time_ns', full_name='blickfeld.protocol.data.PointCloud.Header.start_time_ns', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firmware_version', full_name='blickfeld.protocol.data.PointCloud.Header.firmware_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\252\265\030\027v[0-9]+\\.[0-9]+\\.[0-9]+'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hardware_variant', full_name='blickfeld.protocol.data.PointCloud.Header.hardware_variant', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=606,
)

_POINTCLOUD = _descriptor.Descriptor(
  name='PointCloud',
  full_name='blickfeld.protocol.data.PointCloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.protocol.data.PointCloud.header', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame', full_name='blickfeld.protocol.data.PointCloud.frame', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanline', full_name='blickfeld.protocol.data.PointCloud.scanline', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_POINTCLOUD_HEADER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.data.PointCloud.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=179,
  serialized_end=614,
)

_POINTCLOUD_HEADER.fields_by_name['hardware_variant'].enum_type = blickfeld_dot_update_dot_hardware__pb2._HARDWAREVARIANT
_POINTCLOUD_HEADER.containing_type = _POINTCLOUD
_POINTCLOUD.fields_by_name['header'].message_type = _POINTCLOUD_HEADER
_POINTCLOUD.fields_by_name['frame'].message_type = blickfeld_dot_data_dot_frame__pb2._FRAME
_POINTCLOUD.fields_by_name['scanline'].message_type = blickfeld_dot_data_dot_scanline__pb2._SCANLINE
_POINTCLOUD.oneofs_by_name['data'].fields.append(
  _POINTCLOUD.fields_by_name['header'])
_POINTCLOUD.fields_by_name['header'].containing_oneof = _POINTCLOUD.oneofs_by_name['data']
_POINTCLOUD.oneofs_by_name['data'].fields.append(
  _POINTCLOUD.fields_by_name['frame'])
_POINTCLOUD.fields_by_name['frame'].containing_oneof = _POINTCLOUD.oneofs_by_name['data']
_POINTCLOUD.oneofs_by_name['data'].fields.append(
  _POINTCLOUD.fields_by_name['scanline'])
_POINTCLOUD.fields_by_name['scanline'].containing_oneof = _POINTCLOUD.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['PointCloud'] = _POINTCLOUD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointCloud = _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), dict(

  Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
    DESCRIPTOR = _POINTCLOUD_HEADER,
    __module__ = 'blickfeld.data.point_cloud_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.PointCloud.Header)
    ))
  ,
  DESCRIPTOR = _POINTCLOUD,
  __module__ = 'blickfeld.data.point_cloud_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.PointCloud)
  ))
_sym_db.RegisterMessage(PointCloud)
_sym_db.RegisterMessage(PointCloud.Header)


DESCRIPTOR._options = None
_POINTCLOUD_HEADER.fields_by_name['legacy_cube_serial_number']._options = None
_POINTCLOUD_HEADER.fields_by_name['cube_serial_number']._options = None
_POINTCLOUD_HEADER.fields_by_name['firmware_version']._options = None
# @@protoc_insertion_point(module_scope)
