# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/common.proto',
  package='blickfeld.protocol',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x16\x62lickfeld/common.proto\x12\x12\x62lickfeld.protocol\x1a\x17\x62lickfeld/options.proto\".\n\nValueRange\x12\x0f\n\x07minimum\x18\x01 \x01(\x02\x12\x0f\n\x07maximum\x18\x02 \x01(\x02\"B\n\x12OptionalValueRange\x12\x15\n\x07minimum\x18\x01 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x15\n\x07maximum\x18\x02 \x01(\x02\x42\x04\xb0\xb5\x18\x01')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])




_VALUERANGE = _descriptor.Descriptor(
  name='ValueRange',
  full_name='blickfeld.protocol.ValueRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minimum', full_name='blickfeld.protocol.ValueRange.minimum', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.ValueRange.maximum', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=117,
)


_OPTIONALVALUERANGE = _descriptor.Descriptor(
  name='OptionalValueRange',
  full_name='blickfeld.protocol.OptionalValueRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minimum', full_name='blickfeld.protocol.OptionalValueRange.minimum', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.OptionalValueRange.maximum', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=185,
)

DESCRIPTOR.message_types_by_name['ValueRange'] = _VALUERANGE
DESCRIPTOR.message_types_by_name['OptionalValueRange'] = _OPTIONALVALUERANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ValueRange = _reflection.GeneratedProtocolMessageType('ValueRange', (_message.Message,), dict(
  DESCRIPTOR = _VALUERANGE,
  __module__ = 'blickfeld.common_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.ValueRange)
  ))
_sym_db.RegisterMessage(ValueRange)

OptionalValueRange = _reflection.GeneratedProtocolMessageType('OptionalValueRange', (_message.Message,), dict(
  DESCRIPTOR = _OPTIONALVALUERANGE,
  __module__ = 'blickfeld.common_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.OptionalValueRange)
  ))
_sym_db.RegisterMessage(OptionalValueRange)


_OPTIONALVALUERANGE.fields_by_name['minimum']._options = None
_OPTIONALVALUERANGE.fields_by_name['maximum']._options = None
# @@protoc_insertion_point(module_scope)
